==> bonita-server-6.3.9-sources.jar: org/bonitasoft/engine/core/process/definition/model/SActivityDefinition.java <==
/**
 * Copyright (C) 2011-2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.definition.model;

import java.util.List;

import org.bonitasoft.engine.core.operation.model.SOperation;
import org.bonitasoft.engine.core.process.definition.model.event.SBoundaryEventDefinition;
import org.bonitasoft.engine.data.definition.model.SDataDefinition;

/**
 * @author Elias Ricken de Medeiros
 * @author Zhao Na
 * @author Matthieu Chaffotte
 */
public interface SActivityDefinition extends SFlowNodeDefinition {

    SLoopCharacteristics getLoopCharacteristics();

    List<SDataDefinition> getSDataDefinitions();

    List<SOperation> getSOperations();

    List<SBoundaryEventDefinition> getBoundaryEventDefinitions();

    SBoundaryEventDefinition getBoundaryEventDefinition(String name) throws SBoundaryEventNotFoundException;
}

==> bonita-server-6.4.0-sources.jar: org/bonitasoft/engine/core/process/definition/model/SActivityDefinition.java <==
/**
 * Copyright (C) 2011, 2014 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.definition.model;

import java.util.List;

import org.bonitasoft.engine.core.operation.model.SOperation;
import org.bonitasoft.engine.core.process.definition.model.event.SBoundaryEventDefinition;
import org.bonitasoft.engine.data.definition.model.SDataDefinition;

/**
 * @author Elias Ricken de Medeiros
 * @author Zhao Na
 * @author Matthieu Chaffotte
 */
public interface SActivityDefinition extends SFlowNodeDefinition {

    SLoopCharacteristics getLoopCharacteristics();

    List<SDataDefinition> getSDataDefinitions();

    List<SBusinessDataDefinition> getBusinessDataDefinitions();

    List<SOperation> getSOperations();
    List<SBoundaryEventDefinition> getBoundaryEventDefinitions();

    SBoundaryEventDefinition getBoundaryEventDefinition(String name) throws SBoundaryEventNotFoundException;

    SBusinessDataDefinition getBusinessDataDefinition(String name);

}
